@@ -25,12 +25,14 @@ will only apply to domain-a.com, as domain-b.com will continue using
 the previous version of the zone configuration. This module makes no
 attempt to detect and account for that.
 """
+from __future__ import absolute_import
+
 import json
 import logging
 import requests
 
 from builtins import object
-from .base import Provider as BaseProvider
+from lexicon.providers.base import Provider as BaseProvider
 
 try:
     import xmlrpclib
@@ -39,6 +41,8 @@ except ImportError:
 
 LOGGER = logging.getLogger(__name__)
 
+NAMESERVER_DOMAINS = ['gandi.net']
+
 def ProviderParser(subparser):
     """Specify arguments for Gandi Lexicon Provider."""
     subparser.add_argument('--auth-token', help="specify Gandi API key")
@@ -50,35 +54,35 @@ class Provider(BaseProvider):
     Note that this implementation will delegates its call to GandiRPCSubProvider
     if RPC protocol is used.
     """
-    def __init__(self, options, engine_overrides=None):
-        super(Provider, self).__init__(options)
+    def __init__(self, config):
+        super(Provider, self).__init__(config)
         self.default_ttl = 3600
-        self.protocol = self.options.get('api_protocol', 'rpc')
+        self.protocol = self._get_provider_option('api_protocol') or 'rpc'
 
         if (self.protocol != 'rpc' and self.protocol != 'rest'):
             raise ValueError("Invalid API protocol specified, should be 'rpc' or 'rest'")
 
         if (self.protocol == 'rpc'):
-            self.rpc_helper = GandiRPCSubProvider(self.options['auth_token'], 
-                                                  self.options.get('api_endpoint', 'https://rpc.gandi.net/xmlrpc/'), 
-                                                  self.options['domain'].lower(),
+            self.rpc_helper = GandiRPCSubProvider(self._get_provider_option('auth_token'), 
+                                                  'https://rpc.gandi.net/xmlrpc/', 
+                                                  self.domain.lower(),
                                                   self._relative_name,
                                                   self._full_name)
         else:
-            self.api_endpoint = self.options.get('api_endpoint', 'https://dns.api.gandi.net/api/v5')
+            self.api_endpoint = 'https://dns.api.gandi.net/api/v5'
 
     def authenticate(self):
         if (self.protocol == 'rpc'):
             domain_id = self.rpc_helper.authenticate()
             self.domain_id = domain_id
         else:
-            self._get('/domains/{0}'.format(self.options['domain']))
-            self.domain_id = self.options['domain'].lower()
+            self._get('/domains/{0}'.format(self.domain))
+            self.domain_id = self.domain.lower()
 
     def create_record(self, type, name, content):
         if (self.protocol == 'rpc'):
             return self.rpc_helper.create_record(type, self._relative_name(name), 
-                                                 content, self.options.get('ttl') or self.default_ttl)
+                                                 content, self._get_lexicon_option('ttl') or self.default_ttl)
 
         current_values = [record['content'] for record in self.list_records(type=type, name=name)]
         if current_values != [content]:
@@ -90,8 +94,8 @@ class Provider(BaseProvider):
             else:
                 record = {'rrset_values': [content]}
                 # add the ttl, if this is a new record
-                if self.options.get('ttl'):
-                    record['rrset_ttl'] = self.options.get('ttl')
+                if self._get_lexicon_option('ttl'):
+                    record['rrset_ttl'] = self._get_lexicon_option('ttl')
                 self._post(url, record)
         LOGGER.debug('create_record: %s', True)
         return True
@@ -226,7 +230,7 @@ class Provider(BaseProvider):
         default_headers = {
             'Accept': 'application/json',
             'Content-Type': 'application/json',
-            'X-Api-Key': self.options.get('auth_token')
+            'X-Api-Key': self._get_provider_option('auth_token')
         }
         if not url.startswith(self.api_endpoint):
             url = self.api_endpoint + url
