@@ -1,7 +1,6 @@
 """Rackspace provider implementation"""
 
 from __future__ import absolute_import
-from __future__ import print_function
 
 import json
 import logging
@@ -9,10 +8,12 @@ import time
 
 import requests
 
-from .base import Provider as BaseProvider
+from lexicon.providers.base import Provider as BaseProvider
 
 logger = logging.getLogger(__name__)
 
+NAMESERVER_DOMAINS = ['rackspacecloud.com']
+
 def _async_request_completed(payload):
     """Looks into an async response payload to see if the requested job has finished."""
     if payload['status'] == 'COMPLETED':
@@ -22,40 +23,35 @@ def _async_request_completed(payload):
     return False
 
 def ProviderParser(subparser):
-    subparser.add_argument("--auth-account", help="specify account number used to authenticate")
-    subparser.add_argument("--auth-username", help="specify username used to authenticate. Only used if --auth-token is empty.")
-    subparser.add_argument("--auth-api-key", help="specify api key used to authenticate. Only used if --auth-token is empty.")
-    subparser.add_argument("--auth-token", help="specify token used authenticate. If empty, the username and api key will be used to create a token.")
+    subparser.add_argument("--auth-account", help="specify account number for authentication")
+    subparser.add_argument("--auth-username", help="specify username for authentication. Only used if --auth-token is empty.")
+    subparser.add_argument("--auth-api-key", help="specify api key for authentication. Only used if --auth-token is empty.")
+    subparser.add_argument("--auth-token", help="specify token for authentication. If empty, the username and api key will be used to create a token.")
     subparser.add_argument("--sleep-time", type=float, default=1, help="number of seconds to wait between update requests.")
 
 class Provider(BaseProvider):
 
-    def __init__(self, options, engine_overrides=None):
-        super(Provider, self).__init__(options, engine_overrides)
+    def __init__(self, config):
+        super(Provider, self).__init__(config)
         self.domain_id = None
-        self.api_endpoint = self.engine_overrides.get(
-            'api_endpoint',
-            'https://dns.api.rackspacecloud.com/v1.0'
-        )
-        self.auth_api_endpoint = self.engine_overrides.get(
-            'auth_api_endpoint',
-            'https://identity.api.rackspacecloud.com/v2.0'
-        )
+        self.api_endpoint = 'https://dns.api.rackspacecloud.com/v1.0'
+        self.auth_api_endpoint = 'https://identity.api.rackspacecloud.com/v2.0'
 
     def authenticate(self):
-        if not self.options['auth_token']:
+        self._auth_token = self._get_provider_option('auth_token')
+        if not self._auth_token:
             auth_response = self._auth_request('POST', '/tokens', {
                 'auth': {
                     'RAX-KSKEY:apiKeyCredentials': {
-                        'username': self.options['auth_username'],
-                        'apiKey': self.options['auth_api_key']
+                        'username': self._get_provider_option('auth_username'),
+                        'apiKey': self._get_provider_option('auth_api_key')
                     }
                 }
             })
-            self.options['auth_token'] = auth_response['access']['token']['id']
+            self._auth_token = auth_response['access']['token']['id']
 
         payload = self._get('/domains', {
-            'name': self.options['domain']
+            'name': self.domain
         })
 
         if not payload['domains']:
@@ -69,8 +65,8 @@ class Provider(BaseProvider):
     # Create record. If record already exists with the same content, do nothing'
     def create_record(self, type, name, content):
         data = {'records': [{'type': type, 'name': self._full_name(name), 'data': content}]}
-        if self.options.get('ttl'):
-            data['records'][0]['ttl'] = self.options.get('ttl')
+        if self._get_lexicon_option('ttl'):
+            data['records'][0]['ttl'] = self._get_lexicon_option('ttl')
 
         try:
             payload = self._post_and_wait('/domains/{0}/records'.format(self.domain_id), data)
@@ -121,8 +117,8 @@ class Provider(BaseProvider):
             data['name'] = self._full_name(name)
         if content:
             data['data'] = content
-        if self.options.get('ttl'):
-            data['ttl'] = self.options.get('ttl')
+        if self._get_lexicon_option('ttl'):
+            data['ttl'] = self._get_lexicon_option('ttl')
 
         if identifier is None:
             records = self.list_records(type, name)
@@ -165,11 +161,11 @@ class Provider(BaseProvider):
             data = {}
         if query_params is None:
             query_params = {}
-        full_url = (self.api_endpoint + '/{0}' + url).format(self.options.get('auth_account'))
+        full_url = (self.api_endpoint + '/{0}' + url).format(self._get_provider_option('auth_account'))
         r = requests.request(action, full_url, params=query_params,
                              data=json.dumps(data),
                              headers={
-                                 'X-Auth-Token': self.options.get('auth_token'),
+                                 'X-Auth-Token': self._get_provider_option('auth_token'),
                                  'Content-Type': 'application/json'
                              })
         r.raise_for_status()  # if the request fails for any reason, throw an error.
@@ -179,9 +175,7 @@ class Provider(BaseProvider):
     def _request_and_wait(self, action='POST', url='/', data=None, query_params=None):
         result = self._request(action, url, data, query_params)
 
-        sleep_time = self.options.get('sleep_time')
-        if sleep_time == "":
-            sleep_time = "1"
+        sleep_time = self._get_provider_option('sleep_time') or '1'
         sleep_time = float(sleep_time)
 
         while not _async_request_completed(result):
@@ -209,7 +203,7 @@ class Provider(BaseProvider):
         r = requests.request('GET', payload['callbackUrl'], params={'showDetails': 'true'},
                              data={},
                              headers={
-                                 'X-Auth-Token': self.options.get('auth_token'),
+                                 'X-Auth-Token': self._get_provider_option('auth_token'),
                                  'Content-Type': 'application/json'
                              })
 
